#!/bin/sh
gettextize -c
libtoolize -c
aclocal
autoconf
autoheader
automake -c -a --foreign
